Finalize - kombu.utils.finalize — Kombu v1.3.2 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Kombu v1.3.2 documentation »
- API Reference »

# Finalize - kombu.utils.finalize

Taken from multiprocessing.util.Finalize.

class `kombu.utils.finalize.` `Finalize`(obj, callback, args=(), kwargs=None, exitpriority=None)

  Object finalization using weakrefs.

  `cancel`()

    Cancel finalization of the object.

  `still_active`()

### Navigation

- index
- modules |
- next |
- previous |
- Kombu v1.3.2 documentation »
- API Reference »